import React, { useState } from 'react'
import Button from '@mui/material/Button'
import { alpha, Stack, styled, Typography } from '@mui/material'
import IconButton from '@mui/material/IconButton'
import ArrowBackIcon from '@mui/icons-material/ArrowBack'
import { useTranslation } from 'react-i18next'
import { useTheme } from '@mui/material/styles'
import { useRouter } from 'next/router'

export const PrimaryButton = styled(Button)(
    ({
        backgroundColor,
        hoverBackgroundColor,
        borderRadius,
        theme,
        padding,
        color,
    }) => ({
        backgroundColor: backgroundColor,
        borderRadius: borderRadius ? borderRadius : '8px',
        color: theme.palette.neutral[100],
        '&:hover': {
            backgroundColor: alpha(theme.palette.primary.main, 0.8),
            color: hoverBackgroundColor,
        },
        [theme.breakpoints.down('sm')]: {
            padding: padding ? padding : '',
        },
    })
)

const BackButton = styled(IconButton)(({ theme }) => ({
    // transform: 'rotate(180deg)',
    right: 0,
    marginLeft: 'auto', // Align to the right
    color: theme.palette.primary.main,
    backgroundColor: theme.palette.background.p, // Change to your desired background color
    '&:hover': {
        color: theme.palette.primary.dark,
        backgroundColor: theme.palette.background.default, // Change to your desired hover background color
    },
}))

export default function FoodOrRestaurant({
    foodOrRestaurant,
    setFoodOrRestaurant,
    handleFilter,
}) {

    const { t, i18n } = useTranslation()
    const currentLanguage = i18n.language
    const theme = useTheme()
    const orangeColor = theme.palette.primary.main
    const isProduct = foodOrRestaurant === 'products'
    const isRestaurant = foodOrRestaurant === 'restaurants'
    const [languageDirection, setLanguageDirection] = React.useState('ltr')

    React.useEffect(() => {
        if (localStorage.getItem('direction')) {
            setLanguageDirection(localStorage.getItem('direction'))
        }
    }, [])

    const handleClick = (value) => {
        setFoodOrRestaurant(value)
    }

    const router = useRouter()
    const handleBack = () => {
        router.back()
    }

    return (
        <>
            {languageDirection && (
                <Stack
                    alignItems="center"
                    justifyContent="space-between" // Align items in a row with space between
                    direction="row"
                    spacing={{ xs: 3, sm: 4, md: 5 }}
                    gap={languageDirection === 'rtl' && '10px'}
                    marginTop={{ xs: '10px', sm: '10px', md: '0px' }}
                >
                    <Stack flex={1} direction="row" gap={1}>
                        <Typography
                            onClick={() => handleClick('products')}
                            fontSize={{ xs: '16px', sm: '20px', md: '20px' }}
                            fontWeight={isProduct ? '700' : '400'}
                            sx={{
                                color: isProduct
                                    ? (theme) => theme.palette.neutral[1000]
                                    : (theme) => theme.palette.neutral[500],
                                cursor: 'pointer',
                            }}
                        >
                            {t('Foods')}
                            <Typography
                                sx={{
                                    borderBottom: isProduct
                                        ? `3px solid ${theme.palette.primary.main}`
                                        : '',
                                    borderRadius: '20px',
                                    marginTop: '4px',
                                }}
                            ></Typography>
                        </Typography>
                        <Typography
                            onClick={() => handleClick('restaurants')}
                            fontSize={{ xs: '16px', sm: '20px', md: '20px' }}
                            fontWeight={isRestaurant ? '700' : '400'}
                            sx={{
                                color: isRestaurant
                                    ? (theme) => theme.palette.neutral[1000]
                                    : (theme) => theme.palette.neutral[500],
                                cursor: 'pointer',
                            }}
                        >
                            {t('Restaurants')}
                            <Typography
                                sx={{
                                    borderBottom: isRestaurant
                                        ? `3px solid ${theme.palette.primary.main}`
                                        : '',
                                    borderRadius: '20px',
                                    marginTop: '4px',
                                }}
                            ></Typography>
                        </Typography>
                    </Stack>

                    <BackButton >
                        <IconButton onClick={handleBack}>
                            <ArrowBackIcon />
                        </IconButton>
                    </BackButton>
                </Stack>
            )}
        </>
    )
}
